
//#define MSG_USE_COLORS

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

#include "mp_msg.h"

extern int verbosity;

void
mp_msg (int module, int level, const char *format, ...)
{
  if (level <= verbosity)
  {
    va_list va;

    va_start (va, format);
    vfprintf (stderr, format, va);
    va_end (va);

    fflush (stderr);
  }
}

